@@ -31,6 +31,7 @@ from cbw_api_toolbox.__routes__ import ROUTE_SECURITY_ISSUES
 from cbw_api_toolbox.__routes__ import ROUTE_SERVERS
 from cbw_api_toolbox.__routes__ import ROUTE_STORED_CREDENTIALS
 from cbw_api_toolbox.__routes__ import ROUTE_USERS
+from cbw_api_toolbox.__routes__ import ROUTE_OS
 from cbw_api_toolbox.cbw_auth import CBWAuth
 
 class CBWApi: # pylint: disable=R0904
@@ -44,6 +45,9 @@ class CBWApi: # pylint: disable=R0904
         verify_ssl=False,
     ):
 
+        self.verify_ssl = verify_ssl
+        self.logger = logging.getLogger(self.__class__.__name__)
+
         try:
             self.api_url = api_url if api_url is not None else environ["CBW_API_URL"]
             self.api_key = api_key if api_key is not None else environ["CBW_API_KEY"]
@@ -51,15 +55,11 @@ class CBWApi: # pylint: disable=R0904
                 secret_key if secret_key is not None else environ["CBW_SECRET_KEY"]
             )
         except KeyError as error:
-            raise TypeError(
-                (
-                    "CBWApi is missing one of its argument. "
-                    f"You can use the environnement variable {error}."
-                )
-            ) from error
-
-        self.verify_ssl = verify_ssl
-        self.logger = logging.getLogger(self.__class__.__name__)
+            self.logger.error(
+                "CBWApi is missing one of its argument. You can use the environnement variable %s.",
+                error
+            )
+            sys.exit(1)
 
     def _build_route(self, params):
         return functools.reduce(lambda base_url, arg: urljoin(f"{base_url}/", arg), [self.api_url] + params)
@@ -786,3 +786,20 @@ class CBWApi: # pylint: disable=R0904
             return None
 
         return response
+
+    def operating_systems(self):
+        """GET request to /api/v3/os to list all the operating systems"""
+        response = self._request("GET", [ROUTE_OS])
+        if response.status_code != 200:
+            logging.error("Error::{}".format(response.text))
+            return None
+        return self._cbw_parser(response)
+
+    def server_reboot(self, server_id, params=None):
+        """POST request to /api/v3/vulnerabilities/servers/<id>/reboot to reboot a server"""
+        response = self._request("PATCH", [ROUTE_SERVERS, server_id, "reboot"], params)
+        if response.status_code != 200:
+            logging.error("Error::{}".format(response.text))
+            return None
+
+        return self._cbw_parser(response)
